pub struct Producer<T> { /* private fields */ }Expand description
The producer endpoint of an MPSC queue.
This endpoint can be cloned to create additional producers. Each clone maintains its own cached state for performance.
Implementations
Sourceimpl<T> Producer<T>
impl<T> Producer<T>
Sourcepub fn push(&mut self, value: T) -> Result<(), Full<T>>
pub fn push(&mut self, value: T) -> Result<(), Full<T>>
Pushes a value into the queue.
Returns Err(Full(value)) if the queue is full, returning ownership
of the value to the caller for backpressure handling.
This method spins internally on CAS contention but returns immediately when the queue is actually full.
Sourcepub fn is_disconnected(&self) -> bool
pub fn is_disconnected(&self) -> bool
Returns true if the consumer has been dropped.
With multiple producers, this returns true only when this is the
last handle (all other producers and the consumer are dropped).